SOAP based web services compliant with (WS-I) Basic Profile
-------

**Description:**

Simple Soap Binding Profile is a specification from the Web Services Interoperability industry consortium. It 
is intended as a support profile for the WS-I Basic Profile. This profile defines the way WSDL
documents are to bind operations to a specific transport protocol SOAP.

**Solution:**

Verify that the SOAP based web services are making use of the WS-I Basic profile.

Source:
http://www.ws-i.org/Profiles/SimpleSoapBindingProfile-1.0.html
